Hejmdal
=======
Hejmdal is a package for handling the backend for python systems handling variometer data. One can use it to get data from various sources, such as through sql queries to databases, reading from files, or downloading of data directly from servers. One can then work with the data directly, or use one of the provided tools to turn it into other recognisable formats. The package will by default keep the data in memory, while the resulting output formats also allows one to save them to files when needed.
